@@ -617,7 +617,7 @@ def feed_file(driven_doc, filepath, root_dir, line_feed, file_feed, print_feed,
 
 def feed_line(driven_doc, line, from_filekey, line_feed, print_feed, rcrsn_lvl):
     if print_feed:
-        print ' '*(4*rcrsn_lvl)+'| '+line
+        print ' '*(4*rcrsn_lvl)+'| '+line.rstrip()
     if line_feed:
         print 'docdriven:    '+line.rstrip()
     driven_doc.feed_line(line, from_filekey)
